import { Server } from "socket.io";
import {TSocket} from "../utilities/Types";
import CharacterRepository from "../repositories/CharacterRepository";
import ZoneManager from "../ZoneManager";

type SocketResponseT = {
    position_x: number,
    position_y: number,
}

export default function (socket: TSocket, io: Server) {
    socket.on('character:move', async (data: SocketResponseT) => {
        try {
            console.log('character:move requested', data);

            if (!socket.character) {
                console.log('character:move error', 'Character not found');
                return;
            }

            socket.character.position_x = data.position_x;
            socket.character.position_y = data.position_y;

            await CharacterRepository.update(socket.character);
            ZoneManager.updateCharacterInZone(socket.character.zoneId, socket.character);
            console.log(socket.character);

            io.in(socket.character.zoneId.toString()).emit('character:moved', socket.character);
        } catch (error: any) {
            console.log('character:move error', error);
        }
    });
}